# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
♻️ Simplify init | [12](https://github.com/laminlabs/bionty/pull/12) | [falexwolf](https://github.com/falexwolf) | 2024-03-08 | 0.42.0
🚑️ Fix reload | [11](https://github.com/laminlabs/bionty/pull/11) | [sunnyosun](https://github.com/sunnyosun) | 2024-03-07 |
🏗️ Enable `ln.connect()` in lamindb | [9](https://github.com/laminlabs/bionty/pull/9) | [falexwolf](https://github.com/falexwolf) | 2024-03-07 |
🚚 Rename dev to core | [8](https://github.com/laminlabs/bionty/pull/8) | [falexwolf](https://github.com/falexwolf) | 2024-02-29 |
📝 Updated landing page | [7](https://github.com/laminlabs/bionty/pull/7) | [sunnyosun](https://github.com/sunnyosun) | 2024-02-06 |
💚 Fix docs | [6](https://github.com/laminlabs/bionty/pull/6) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-31 |
⬆️ Update lb | [5](https://github.com/laminlabs/bionty/pull/5) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-31 | 0.40.2
👷 Upload docs | [4](https://github.com/laminlabs/bionty/pull/4) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-31 | 0.40.1
💚 Fix docs | [3](https://github.com/laminlabs/bionty/pull/3) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-30 |
📝 Updated readme | [2](https://github.com/laminlabs/bionty/pull/2) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-30 |
🎨 Import orms from lb | [1](https://github.com/laminlabs/bionty/pull/1) | [sunnyosun](https://github.com/sunnyosun) | 2024-01-30 |
